@@ -15,8 +15,8 @@ import javax.mail.PasswordAuthentication;
 import javax.mail.Session;
 import javax.mail.Transport;
 
+import org.gcube.applicationsupportlayer.social.ScopeBeanExt;
 import org.gcube.common.encryption.StringEncrypter;
-import org.gcube.common.portal.PortalContext;
 import org.gcube.common.resources.gcore.ServiceEndpoint;
 import org.gcube.common.resources.gcore.ServiceEndpoint.AccessPoint;
 import org.gcube.common.scope.api.ScopeProvider;
@@ -40,13 +40,15 @@ public class EmailNotificationsConsumer extends Thread {
 	private String mailServiceHost = "localhost";
 	private String mailServicePort = "25";
 
-	public EmailNotificationsConsumer() {
+	public EmailNotificationsConsumer(String context) {
 		super();
 		_log.info("EmailNotificationsConsumer thread started at " + new Date() + " trying to fetch SMTP configuration from infrastructure ...");
-
 		//query
 		try {
-			List<ServiceEndpoint> resources = getConfigurationFromIS();
+			String currScope = 	ScopeProvider.instance.get();
+			ScopeBeanExt sbe = new ScopeBeanExt(context);
+			String infraContext = sbe.getInfrastructureScope();
+			List<ServiceEndpoint> resources = getConfigurationFromIS(infraContext);
 			if (resources.size() > 1) {
 				_log.error("Too many Service Endpoints having name " + SERVICE_ENDPOINT_NAME +" in this scope having Category " + SERVICE_ENDPOINT_CATEGORY);
 			}
@@ -59,11 +61,8 @@ public class EmailNotificationsConsumer extends Thread {
 					mailServiceHost = found.address().split(":")[0].trim();
 					mailServicePort = found.address().split(":")[1].trim();
 					smtpUsername = found.username();
-
-					PortalContext context = PortalContext.getConfiguration();	
-					String currScope = 	ScopeProvider.instance.get();
-					String scope = "/" + context.getInfrastructureName();
-					ScopeProvider.instance.set(scope);
+				
+					ScopeProvider.instance.set(infraContext);
 					smtpPasswd = StringEncrypter.getEncrypter().decrypt(found.password());
 					ScopeProvider.instance.set(currScope);
 					_log.info("Found SMTP Configuration: "+mailServiceHost+":"+mailServicePort+ " usr="+smtpUsername+ " pwd=*******");
@@ -76,12 +75,13 @@ public class EmailNotificationsConsumer extends Thread {
 	}
 	/**
 	 * 
+	 * @param context 
 	 * @return the
 	 * @throws Exception
 	 */
-	private List<ServiceEndpoint> getConfigurationFromIS() throws Exception  {
-		PortalContext context = PortalContext.getConfiguration();		
-		String scope = "/" + context.getInfrastructureName();
+	private List<ServiceEndpoint> getConfigurationFromIS(String infraContext) throws Exception  {
+;		
+		String scope = infraContext;
 		String currScope = 	ScopeProvider.instance.get();
 		ScopeProvider.instance.set(scope);
 		SimpleQuery query = queryFor(ServiceEndpoint.class);
@@ -127,13 +127,13 @@ public class EmailNotificationsConsumer extends Thread {
 				_log.debug("Emails Buffer not empty, sending emails ");
 				Transport t = null;
 				try {
-					t = session.getTransport();
+					t = session.getTransport("smtp");
 					t.connect();
 
 					//sync method to ensure the producer do not put new emails in the meantime
 					synchronized(EmailPlugin.BUFFER_EMAILS){
 						for (NotificationMail mail : EmailPlugin.BUFFER_EMAILS) {
-							Message m = EmailPlugin.getMessageNotification(session, mail.getNotification2Send(), mail.getVreName(), mail.getPortalName(), mail.getSenderEmail(), mail.getHashtags());
+							Message m = mail.getMessageNotification(session);
 							if (m != null) {
 								m.saveChanges();
 								Address[] addresses = m.getAllRecipients();
