@@ -2,9 +2,12 @@ package org.gcube.applicationsupportlayer.social.mailing;
 
 import java.text.Format;
 import java.text.SimpleDateFormat;
+import java.util.Arrays;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
 
-import org.gcube.common.portal.GCubePortalConstants;
+import org.gcube.applicationsupportlayer.social.ApplicationNotificationsManager;
 import org.gcube.portal.databook.shared.Comment;
 import org.gcube.portal.databook.shared.Feed;
 import org.gcube.portal.databook.shared.Notification;
@@ -61,7 +64,7 @@ public class SocialMailingUtil {
 		}
 
 		String sender = notification2Save.getSenderFullName();
-	
+
 		String portalHost = portalURL.replaceAll("https://", "");
 		portalHost = portalHost.replaceAll("http://", "");
 
@@ -74,8 +77,6 @@ public class SocialMailingUtil {
 				notification2Save.getType() == NotificationType.MENTION || 
 				notification2Save.getType() == NotificationType.OWN_COMMENT) {
 			body.append("<div>").append(WRITE_ABOVE_TO_REPLY).append("</div><br />");
-
-
 		}
 
 		String attachmentsNotice = "";
@@ -100,13 +101,13 @@ public class SocialMailingUtil {
 		.append("<a href=\"").append(portalURL).append("\" style=\"color:#3B5998;text-decoration:none\" target=\"_blank\">").append(portalHost)
 		.append("</a>. ")
 		.append(" If you don't want to receive these emails in the future, please <a href=\"")
-		.append(portalURL).append(siteLandingPagePath).append(GCubePortalConstants.USER_NOTIFICATION_FRIENDLY_URL).append("?showsettings=true")
+		.append(portalURL).append(siteLandingPagePath).append(ApplicationNotificationsManager.USER_NOTIFICATION_FRIENDLY_URL).append("?showsettings=true")
 		.append("\" style=\"color:#3b5998;text-decoration:none\" target=\"_blank\">unsubscribe</a>.")
 		.append("</div></p>")
 		.append("<p><div style=\"color:#999999; font-size:10px; font-family:'lucida grande',tahoma,verdana,arial,sans-serif; padding-top:15px;\">")
 		.append("WARNING / LEGAL TEXT: This message is intended only for the use of the individual or entity to which it is addressed and may contain ")
 		.append("information which is privileged, confidential, proprietary, or exempt from disclosure under applicable law. If you are not the intended recipient or the person responsible for delivering the message to the intended recipient, you are strictly prohibited from disclosing, distributing, copying, or in any way using this message.")
-		.append("If you have received this communication in error, please notify the <sender> and destroy and delete any copies you may have received.")
+		.append("If you have received this communication in error, please notify the sender and destroy and delete any copies you may have received.")
 		.append("</div></p>")
 		.append("</body>");
 
@@ -145,7 +146,7 @@ public class SocialMailingUtil {
 			}
 		}
 		String sender = notification2Save.getSenderFullName();
-		
+
 		String portalHost = portalURL.replaceAll("https://", "");
 		portalHost = portalHost.replaceAll("http://", "");
 
@@ -177,7 +178,7 @@ public class SocialMailingUtil {
 		.append(" by ")
 		.append(portalHost)
 		.append(" If you don't want to receive these emails in the future, please unsubscribe here: ")
-		.append(portalURL).append(siteLandingPagePath).append(GCubePortalConstants.USER_NOTIFICATION_FRIENDLY_URL).append("?showsettings=true");
+		.append(portalURL).append(siteLandingPagePath).append(ApplicationNotificationsManager.USER_NOTIFICATION_FRIENDLY_URL).append("?showsettings=true");
 
 		return body.toString();
 
@@ -193,7 +194,7 @@ public class SocialMailingUtil {
 	 * @param vreName
 	 * @return
 	 */
-	protected static String getSubjectByNotificationType(Notification notification2Save, String vreName, String userFirstName, String ...optionalParams) {		
+	protected static String getSubjectByNotificationType(Notification notification2Save, String vreName, String userFirstName, Set<String> mentionedVReGroups, String ...optionalParams) {		
 		switch (notification2Save.getType()) {
 		case LIKE:
 			return notification2Save.getSenderFullName()+" liked your post in " + (vreName == null? "" : vreName);
@@ -229,17 +230,23 @@ public class SocialMailingUtil {
 			return notification2Save.getSenderFullName() + " mentioned you in " + (vreName == null? "" : vreName);
 		case POST_ALERT: 
 			String toReturn = notification2Save.getSenderFullName() + " posted on " + vreName;
+			if(mentionedVReGroups != null && !mentionedVReGroups.isEmpty()){
+				for (String mentionedGroup : mentionedVReGroups) {
+					toReturn += " [" + mentionedGroup + "]";
+				}
+			}
 			if (optionalParams != null) { //in this case optionalParams are the hashtags
-				for (int i = 0; i < optionalParams.length; i++) 
-					toReturn += " " + optionalParams[i];	
+				Set<String> hashtags = new HashSet<String>(Arrays.asList(optionalParams));
+				for (String hashtag : hashtags) 
+					toReturn += " " + hashtag;	
 			}
 			return toReturn;
 		case REQUEST_CONNECTION:
 			return "Connection request";
 		case JOB_COMPLETED_NOK:
-			return "Job Completed";
+			return notification2Save.getSubjectid() + "'s job status notification"; // i.e. Name of the job  + ...
 		case JOB_COMPLETED_OK:
-			return "Job Completed";
+			return notification2Save.getSubjectid() + "'s job status notification"; // i.e. Name of the job  + ...
 		case CALENDAR_ADDED_EVENT:
 			return vreName +": New event in a shared calendar";
 		case CALENDAR_UPDATED_EVENT:
@@ -309,10 +316,12 @@ public class SocialMailingUtil {
 			actionLink.append("\">").append(" Go to Contacts Center").append("</a>");
 			break;
 		case JOB_COMPLETED_NOK:
-			actionLink.append("\">").append(" Go to Application").append("</a>");
+			//actionLink.append("\">").append(" Go to Application").append("</a>");
+			actionLink.append("\">").append("").append("</a>");
 			break;
 		case JOB_COMPLETED_OK:
-			actionLink.append("\">").append(" Go to Application").append("</a>");
+			//actionLink.append("\">").append(" Go to Application").append("</a>");
+			actionLink.append("\">").append("").append("</a>");
 			break;
 		case CALENDAR_ADDED_EVENT:
 			actionLink.append("\">").append(" Go to Calendar").append("</a>");
@@ -396,69 +405,72 @@ public class SocialMailingUtil {
 
 		try{
 
-			if(notification2Save.getType().equals(NotificationType.POST_ALERT) || feed == null)
-				return "";
+			if (notification2Save.getType() == NotificationType.COMMENT ||
+					notification2Save.getType() == NotificationType.OWN_COMMENT ||  
+							notification2Save.getType() == NotificationType.LIKE ||
+									notification2Save.getType() == NotificationType.MENTION){
 
-			String htmlPost = "<br />" + "<br />----<p>Original post:</p>";
-			// data formatter
-			Format formatter = new SimpleDateFormat("yyyy-MM-dd hh:mm a");
+				String htmlPost = "<br />" + "<br />----<p>Original post:</p>";
+				// data formatter
+				Format formatter = new SimpleDateFormat("yyyy-MM-dd hh:mm a");
 
-			// escape html
-			String feedTextNoHtml = convertHTML2Text(feed.getDescription());
+				// escape html
+				String feedTextNoHtml = convertHTML2Text(feed.getDescription());
 
-			// build up html post + comments
-			if(notification2Save.getType() == NotificationType.POST_ALERT || (comments.size() == 0 && notification2Save.getType() == NotificationType.MENTION))
-				htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;padding-left: 15px;  "
-						+ "font-style: italic; font-weight:bold\">"
-						+ feed.getFullName() 
-						+ ": " 
-						+ (feedTextNoHtml.length() > 30 ? feedTextNoHtml.substring(0, 30) + " ..." : feedTextNoHtml) 
-						+ "<p style=\"font-family:Lucida Grande,"
-						+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
-						+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(feed.getTime()) + "</p>"
-						+"</div>";
-			else
-				htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;padding-left: 15px;  "
-						+ "font-style: italic\">"
-						+ feed.getFullName() 
-						+ ": " 
-						+ (feedTextNoHtml.length() > 30 ? feedTextNoHtml.substring(0, 30) + " ..." : feedTextNoHtml) 
-						+ "<p style=\"font-family:Lucida Grande,"
-						+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
-						+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(feed.getTime()) + "</p>"
-						+"</div>";
+				// build up html post + comments
+				if(notification2Save.getType() == NotificationType.POST_ALERT || (comments.size() == 0 && notification2Save.getType() == NotificationType.MENTION))
+					htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;padding-left: 15px;  "
+							+ "font-style: italic; font-weight:bold\">"
+							+ feed.getFullName() 
+							+ ": " 
+							+ (feedTextNoHtml.length() > 30 ? feedTextNoHtml.substring(0, 30) + " ..." : feedTextNoHtml) 
+							+ "<p style=\"font-family:Lucida Grande,"
+							+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
+							+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(feed.getTime()) + "</p>"
+							+"</div>";
+				else
+					htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;padding-left: 15px;  "
+							+ "font-style: italic\">"
+							+ feed.getFullName() 
+							+ ": " 
+							+ (feedTextNoHtml.length() > 30 ? feedTextNoHtml.substring(0, 30) + " ..." : feedTextNoHtml) 
+							+ "<p style=\"font-family:Lucida Grande,"
+							+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
+							+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(feed.getTime()) + "</p>"
+							+"</div>";
 
-			if(comments != null)
-				for (int i = 0; i < comments.size(); i++) {
+				if(comments != null)
+					for (int i = 0; i < comments.size(); i++) {
 
-					String commentTextNoHtml = comments.get(i).getText().replaceAll("&amp;", "&");
+						String commentTextNoHtml = comments.get(i).getText().replaceAll("&amp;", "&");
 
-					if((commentKey != null && comments.get(i).getKey().equals(commentKey)) && !(notification2Save.getType() == NotificationType.POST_ALERT)){
-						htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  "
-								+ "border-left: 3px solid #ccc; font-style: italic; font-weight:bold\">"
-								+ comments.get(i).getFullName() 
-								+ ": " 
-								+ commentTextNoHtml 
-								+ "<p style=\"font-family:Lucida Grande,"
-								+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
-								+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(comments.get(i).getTime()) + "</p>"
-								+"</div>";
+						if((commentKey != null && comments.get(i).getKey().equals(commentKey)) && !(notification2Save.getType() == NotificationType.POST_ALERT)){
+							htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  "
+									+ "border-left: 3px solid #ccc; font-style: italic; font-weight:bold\">"
+									+ comments.get(i).getFullName() 
+									+ ": " 
+									+ commentTextNoHtml 
+									+ "<p style=\"font-family:Lucida Grande,"
+									+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
+									+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(comments.get(i).getTime()) + "</p>"
+									+"</div>";
 
-						break;
-					}
-					else
-						htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  "
-								+ "border-left: 3px solid #ccc; font-style: italic;\">"
-								+ comments.get(i).getFullName() 
-								+ ": " 
-								+ commentTextNoHtml 
-								+ "<p style=\"font-family:Lucida Grande,"
-								+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
-								+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(comments.get(i).getTime()) + "</p>"
-								+"</div>";
-				} 
+							break;
+						}
+						else
+							htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  "
+									+ "border-left: 3px solid #ccc; font-style: italic;\">"
+									+ comments.get(i).getFullName() 
+									+ ": " 
+									+ commentTextNoHtml 
+									+ "<p style=\"font-family:Lucida Grande,"
+									+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
+									+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(comments.get(i).getTime()) + "</p>"
+									+"</div>";
+					} 
 
-			return htmlPost;
+				return htmlPost;
+			}
 		}catch(Exception e){
 			_log.error("Unable to reconstruct html discussion to put into the email body.", e);
 		}
@@ -477,45 +489,48 @@ public class SocialMailingUtil {
 
 		try{
 
-			if(notification2Save.getType().equals(NotificationType.POST_ALERT) || feed == null)
-				return "";
+			if (notification2Save.getType() == NotificationType.COMMENT ||
+					notification2Save.getType() == NotificationType.OWN_COMMENT ||  
+							notification2Save.getType() == NotificationType.LIKE ||
+									notification2Save.getType() == NotificationType.MENTION){
 
-			// build discussion
-			String discussion = "\n\n----\n\nOriginal post:";
+				// build discussion
+				String discussion = "\n\n----\n\nOriginal post:";
 
-			// data formatter
-			Format formatter = new SimpleDateFormat("yyyy-MM-dd hh:mm a");
+				// data formatter
+				Format formatter = new SimpleDateFormat("yyyy-MM-dd hh:mm a");
 
-			// escape html
-			String feedTextNoHtml = convertHTML2Text(feed.getDescription());
-
-			// build up  post + comments
-			discussion += 
-					"\n"
-							+ "["  + formatter.format(feed.getTime())  + "] " 
-							+ feed.getFullName() 
-							+ ": " 
-							+ (feedTextNoHtml.length() > 200 ? feedTextNoHtml.substring(0, 200) + " ..." : feedTextNoHtml)
-							+ "\n";
-
-
-			for (int i = 0; i < comments.size(); i++) {
-
-				String commentTextNoHtml = convertHTML2Text(comments.get(i).getText());
+				// escape html
+				String feedTextNoHtml = convertHTML2Text(feed.getDescription());
 
+				// build up  post + comments
 				discussion += 
-						"\t"
-								+ "["  + formatter.format(comments.get(i).getTime())  + "] " 
-								+ comments.get(i).getFullName() 
+						"\n"
+								+ "["  + formatter.format(feed.getTime())  + "] " 
+								+ feed.getFullName() 
 								+ ": " 
-								+ commentTextNoHtml 
+								+ (feedTextNoHtml.length() > 200 ? feedTextNoHtml.substring(0, 200) + " ..." : feedTextNoHtml)
 								+ "\n";
 
-				if(commentKey != null && comments.get(i).getKey().equals(commentKey))
-					break;
-			}
 
-			return discussion;
+				for (int i = 0; i < comments.size(); i++) {
+
+					String commentTextNoHtml = convertHTML2Text(comments.get(i).getText());
+
+					discussion += 
+							"\t"
+									+ "["  + formatter.format(comments.get(i).getTime())  + "] " 
+									+ comments.get(i).getFullName() 
+									+ ": " 
+									+ commentTextNoHtml 
+									+ "\n";
+
+					if(commentKey != null && comments.get(i).getKey().equals(commentKey))
+						break;
+				}
+
+				return discussion;
+			}
 		}
 		catch(Exception e){
 			_log.error("Unable to reconstruct plain text discussion to put into the email body.", e);
